@@ -6,7 +6,8 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     RocsSimilarity, ParallelRocsSimilarity, PredictivePropertyComponent, SelectivityComponent, \
     SASComponent, MolWeight, PSA, RotatableBonds, HBD_Lipinski, HBA_Lipinski, \
     NumRings, AZlogD74, HLMClint, SlogP, \
-    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength
+    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength, \
+    NumberOfStereoCenters
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
@@ -36,6 +37,7 @@ class ScoreComponentFactory:
             enum.NUM_HBA_LIPINSKI: HBA_Lipinski,
             enum.NUM_RINGS: NumRings,
             enum.SLOGP: SlogP,
+            enum.NUMBER_OF_STEREO_CENTERS: NumberOfStereoCenters,
             enum.PARALLEL_ROCS_SIMILARITY: ParallelRocsSimilarity,
             enum.AZ_LOGD74: AZlogD74,
             enum.HLM_CLINT: HLMClint,
